@@ -1,13 +1,15 @@
-from .modules_repo import ModulesRepo
-from .create import ModuleCreate
-from .test_yml_builder import ModulesTestYmlBuilder
-from .lint import ModuleLint
 from .bump_versions import ModuleVersionBumper
-from .module_utils import ModuleException
-from .list import ModuleList
-from .install import ModuleInstall
-from .update import ModuleUpdate
-from .remove import ModuleRemove
+from .create import ModuleCreate
 from .info import ModuleInfo
-from .mulled import MulledImageNameGenerator
+from .install import ModuleInstall
+from .lint import ModuleLint
+from .list import ModuleList
 from .module_test import ModulesTest
+from .module_utils import ModuleException
+from .modules_json import ModulesJson
+from .modules_repo import ModulesRepo
+from .mulled import MulledImageNameGenerator
+from .patch import ModulePatch
+from .remove import ModuleRemove
+from .test_yml_builder import ModulesTestYmlBuilder
+from .update import ModuleUpdate
