@@ -2,11 +2,11 @@
 """ Tests covering the command-line code.
 """
 
-import nf_core.__main__
+from unittest import mock
 
 from click.testing import CliRunner
-import mock
-import unittest
+
+import nf_core.__main__
 
 
 @mock.patch("nf_core.__main__.nf_core_cli")
