@@ -2,19 +2,20 @@
 """ Tests covering the pipeline schema code.
 """
 
-import nf_core.schema
-
-import click
 import json
-import mock
 import os
-import pytest
-import requests
 import shutil
 import tempfile
 import unittest
+from unittest import mock
+
+import pytest
+import requests
 import yaml
 
+import nf_core.create
+import nf_core.schema
+
 from .utils import with_temporary_file, with_temporary_folder
 
 
@@ -25,11 +26,15 @@ class TestSchema(unittest.TestCase):
         """Create a new PipelineSchema object"""
         self.schema_obj = nf_core.schema.PipelineSchema()
         self.root_repo_dir = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
-        # Copy the template to a temp directory so that we can use that for tests
+
+        # Create a test pipeline in temp directory
         self.tmp_dir = tempfile.mkdtemp()
         self.template_dir = os.path.join(self.tmp_dir, "wf")
-        template_dir = os.path.join(self.root_repo_dir, "nf_core", "pipeline-template")
-        shutil.copytree(template_dir, self.template_dir)
+        create_obj = nf_core.create.PipelineCreate(
+            "test_pipeline", "", "", outdir=self.template_dir, no_git=True, plain=True
+        )
+        create_obj.init_pipeline()
+
         self.template_schema = os.path.join(self.template_dir, "nextflow_schema.json")
 
     def tearDown(self):
@@ -41,20 +46,18 @@ class TestSchema(unittest.TestCase):
         self.schema_obj.get_schema_path(self.template_dir)
         self.schema_obj.load_lint_schema()
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_load_lint_schema_nofile(self):
         """Check that linting raises properly if a non-existant file is given"""
-        self.schema_obj.get_schema_path("fake_file")
-        self.schema_obj.load_lint_schema()
+        with pytest.raises(AssertionError):
+            self.schema_obj.get_schema_path("fake_file")
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_load_lint_schema_notjson(self):
         """Check that linting raises properly if a non-JSON file is given"""
         self.schema_obj.get_schema_path(os.path.join(self.template_dir, "nextflow.config"))
-        self.schema_obj.load_lint_schema()
+        with pytest.raises(AssertionError):
+            self.schema_obj.load_lint_schema()
 
     @with_temporary_file
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_load_lint_schema_noparams(self, tmp_file):
         """
         Check that linting raises properly if a JSON file is given without any params
@@ -63,7 +66,8 @@ class TestSchema(unittest.TestCase):
         with open(tmp_file.name, "w") as fh:
             json.dump({"type": "fubar"}, fh)
         self.schema_obj.get_schema_path(tmp_file.name)
-        self.schema_obj.load_lint_schema()
+        with pytest.raises(AssertionError):
+            self.schema_obj.load_lint_schema()
 
     def test_get_schema_path_dir(self):
         """Get schema file from directory"""
@@ -73,22 +77,22 @@ class TestSchema(unittest.TestCase):
         """Get schema file from a path"""
         self.schema_obj.get_schema_path(self.template_schema)
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_get_schema_path_path_notexist(self):
         """Get schema file from a path"""
-        self.schema_obj.get_schema_path("fubar", local_only=True)
+        with pytest.raises(AssertionError):
+            self.schema_obj.get_schema_path("fubar", local_only=True)
 
     def test_get_schema_path_name(self):
         """Get schema file from the name of a remote pipeline"""
         self.schema_obj.get_schema_path("atacseq")
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_get_schema_path_name_notexist(self):
         """
         Get schema file from the name of a remote pipeline
         that doesn't have a schema file
         """
-        self.schema_obj.get_schema_path("exoseq")
+        with pytest.raises(AssertionError):
+            self.schema_obj.get_schema_path("exoseq")
 
     def test_load_schema(self):
         """Try to load a schema from a file"""
@@ -100,7 +104,6 @@ class TestSchema(unittest.TestCase):
         self.schema_obj.schema_filename = self.template_schema
         self.schema_obj.load_schema()
         docs = self.schema_obj.print_documentation()
-        print(docs)
         assert self.schema_obj.schema["title"] in docs
         assert self.schema_obj.schema["description"] in docs
         for definition in self.schema_obj.schema.get("definitions", {}).values():
@@ -134,10 +137,10 @@ class TestSchema(unittest.TestCase):
             yaml.dump({"input": "fubar"}, fh)
         self.schema_obj.load_input_params(tmp_file.name)
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_load_input_params_invalid(self):
         """Check failure when a non-existent file params file is loaded"""
-        self.schema_obj.load_input_params("fubar")
+        with pytest.raises(AssertionError):
+            self.schema_obj.load_input_params("fubar")
 
     def test_validate_params_pass(self):
         """Try validating a set of parameters against a schema"""
@@ -162,11 +165,11 @@ class TestSchema(unittest.TestCase):
         self.schema_obj.load_schema()
         self.schema_obj.validate_schema(self.schema_obj.schema)
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     def test_validate_schema_fail_noparams(self):
         """Check that the schema validation fails when no params described"""
         self.schema_obj.schema = {"type": "invalidthing"}
-        self.schema_obj.validate_schema(self.schema_obj.schema)
+        with pytest.raises(AssertionError):
+            self.schema_obj.validate_schema(self.schema_obj.schema)
 
     def test_validate_schema_fail_duplicate_ids(self):
         """
@@ -292,7 +295,6 @@ class TestSchema(unittest.TestCase):
     def test_build_schema_param_bool(self):
         """Build a new schema param from a config value (bool)"""
         param = self.schema_obj.build_schema_param("True")
-        print(param)
         assert param == {"type": "boolean", "default": True}
 
     def test_build_schema_param_int(self):
@@ -300,7 +302,7 @@ class TestSchema(unittest.TestCase):
         param = self.schema_obj.build_schema_param("12")
         assert param == {"type": "integer", "default": 12}
 
-    def test_build_schema_param_int(self):
+    def test_build_schema_param_float(self):
         """Build a new schema param from a config value (float)"""
         param = self.schema_obj.build_schema_param("12.34")
         assert param == {"type": "number", "default": 12.34}
@@ -326,37 +328,37 @@ class TestSchema(unittest.TestCase):
 
         param = self.schema_obj.build_schema(test_pipeline_dir, True, False, None)
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     @mock.patch("requests.post")
     def test_launch_web_builder_timeout(self, mock_post):
         """Mock launching the web builder, but timeout on the request"""
         # Define the behaviour of the request get mock
         mock_post.side_effect = requests.exceptions.Timeout()
-        self.schema_obj.launch_web_builder()
+        with pytest.raises(AssertionError):
+            self.schema_obj.launch_web_builder()
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     @mock.patch("requests.post")
     def test_launch_web_builder_connection_error(self, mock_post):
         """Mock launching the web builder, but get a connection error"""
         # Define the behaviour of the request get mock
         mock_post.side_effect = requests.exceptions.ConnectionError()
-        self.schema_obj.launch_web_builder()
+        with pytest.raises(AssertionError):
+            self.schema_obj.launch_web_builder()
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     @mock.patch("requests.post")
     def test_get_web_builder_response_timeout(self, mock_post):
         """Mock checking for a web builder response, but timeout on the request"""
         # Define the behaviour of the request get mock
         mock_post.side_effect = requests.exceptions.Timeout()
-        self.schema_obj.launch_web_builder()
+        with pytest.raises(AssertionError):
+            self.schema_obj.launch_web_builder()
 
-    @pytest.mark.xfail(raises=AssertionError, strict=True)
     @mock.patch("requests.post")
     def test_get_web_builder_response_connection_error(self, mock_post):
         """Mock checking for a web builder response, but get a connection error"""
         # Define the behaviour of the request get mock
         mock_post.side_effect = requests.exceptions.ConnectionError()
-        self.schema_obj.launch_web_builder()
+        with pytest.raises(AssertionError):
+            self.schema_obj.launch_web_builder()
 
     def mocked_requests_post(**kwargs):
         """Helper function to emulate POST requests responses from the web"""
